
#ifndef _C15_ce701_
#define _C15_ce701_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F103_1249(EIF_REFERENCE);
extern void F103_1250(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit701(void);
extern long O1236[];

#ifdef __cplusplus
}
#endif

#endif
